@@ -9,20 +9,24 @@ package Data::Context::Loader::File::JSON;
 use Moose;
 use version;
 use Carp;
+use Scalar::Util;
+use List::Util;
+#use List::MoreUtils;
+use Data::Dumper qw/Dumper/;
 use English qw/ -no_match_vars /;
-use JSON::XS;
 
-our $VERSION     = version->new('0.2.3');
+
+our $VERSION     = version->new('0.2');
 
 extends 'Data::Context::Loader::File';
 
 has '+module' => (
-    default => 'JSON::XS',
+    default => 'JSON',
 );
 
 sub loader {
     my ($self, $file) = @_;
-    return JSON::XS->new->utf8->shrink->decode($file);
+    return JSON->new->utf8->shrink->decode($file);
 }
 
 1;
@@ -35,7 +39,7 @@ Data::Context::Loader::File::JSON - <One-line description of module's purpose>
 
 =head1 VERSION
 
-This documentation refers to Data::Context::Loader::File::JSON version 0.2.3
+This documentation refers to Data::Context::Loader::File::JSON version 0.2
 
 =head1 SYNOPSIS
 
